@@ -261,6 +261,12 @@ setMethod("table", "AtomicList",
             stop("\"table\" method for AtomicList objects ",
                  "can only take one input object")
         x <- args[[1L]]
+        if (!pcompareRecursively(x)) {
+            ## Not sure why callNextMethod() doesn't work. Is it because of
+            ## dispatch on the ellipsis?
+            #return(callNextMethod())
+            return(selectMethod("table", "Vector")(...))
+        }
         y1 <- togroup(PartitioningByWidth(x))
         attributes(y1) <- list(levels=as.character(seq_along(x)),
                                class="factor")
@@ -385,8 +391,8 @@ setMethod("runLength", "CompressedRleList", function(x) {
   width(ranges(x))
 })
 
-setMethod("ranges", "RleList", function(x) {
-  as(lapply(x, ranges), "List")
+setMethod("ranges", "RleList", function(x, use.names=TRUE, use.mcols=FALSE) {
+  as(lapply(x, ranges, use.names=use.names, use.mcols=use.mcols), "List")
 })
 
 diceRangesByList <- function(x, list) {
@@ -397,16 +403,16 @@ diceRangesByList <- function(x, list) {
   ## bit faster.
   hits <- findOverlaps_Ranges_Partitioning(x, listPart,
                                            hit.empty.query.ranges=TRUE)
+  ov <- overlapsRanges(x, listPart, hits)
+  ans_unlistData <- shift(ov, 1L - start(listPart)[subjectHits(hits)])
   ans_partitioning <- PartitioningByEnd(subjectHits(hits), NG=length(list))
-  ans_unlistData <- shift(ranges(hits, x, listPart),
-                          1L - start(listPart)[subjectHits(hits)])
   ans <- relist(ans_unlistData, ans_partitioning)
   names(ans) <- names(list)
   ans
 }
 
 setMethod("ranges", "CompressedRleList",
-    function(x)
+    function(x, use.names=TRUE, use.mcols=FALSE)
     {
       rle <- unlist(x, use.names=FALSE)
       rlePart <- PartitioningByWidth(runLength(rle))
