@@ -78,12 +78,12 @@ setMethod("colnames", "DataFrameList",
             CharacterList(lapply(x, colnames, do.NULL = do.NULL, prefix = prefix))
           })
 
-setMethod("colnames", "SimpleSplitDataFrameList",
+setMethod("colnames", "SplitDataFrameList",
           function(x, do.NULL = TRUE, prefix = "col")
           {
             if (length(x)) {
               nms <- colnames(x[[1]], do.NULL = do.NULL, prefix = prefix)
-              CharacterList(rep(list(nms), length(x)))
+              rep(CharacterList(nms), length(x))
             } else NULL
           })
 
@@ -92,7 +92,7 @@ setMethod("colnames", "CompressedSplitDataFrameList",
           {
             if (length(x)) {
               nms <- colnames(x@unlistData, do.NULL = do.NULL, prefix = prefix)
-              CharacterList(rep(list(nms), length(x)))
+              rep(CharacterList(nms), length(x))
             } else NULL
           })
 
@@ -209,6 +209,7 @@ setReplaceMethod("columnMetadata", "SimpleSplitDataFrameList",
 setReplaceMethod("columnMetadata", "CompressedSplitDataFrameList",
                  function(x, value) {
                    mcols(x@unlistData) <- value
+                   x
                  })
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -389,13 +390,13 @@ setMethod("commonColnames", "CompressedSplitDataFrameList",
           function(x) colnames(unlist(x, use.names=FALSE)))
 
 setMethod("commonColnames", "SplitDataFrameList",
-          function(x) colnames(as.list(x)[[1L]]))
+          function(x) colnames(head(x, 1L))[[1L]])
 
 setAs("SplitDataFrameList", "DataFrame",
     function(from) {
       cols <- sapply(commonColnames(from), function(j) from[,j],
                      simplify=FALSE)
-      DataFrame(cols)
+      DataFrame(cols, check.names=FALSE)
     }
 )
 
