@@ -46,7 +46,7 @@ setMethod("parallelSlotNames", "IRanges",
 
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### Accessor methods.
+### Getters
 ###
 
 setMethod("start", "IRanges", function(x, ...) x@start)
@@ -55,6 +55,25 @@ setMethod("width", "IRanges", function(x) x@width)
 
 setMethod("names", "IRanges", function(x) x@NAMES)
 
+setMethod("ranges", "Ranges",
+    function(x, use.names=TRUE, use.mcols=FALSE)
+    {
+        if (!isTRUEorFALSE(use.names))
+            stop("'use.names' must be TRUE or FALSE")
+        if (!isTRUEorFALSE(use.mcols))
+            stop("'use.mcols' must be TRUE or FALSE")
+        ans_start <- start(x)
+        ans_width <- width(x)
+        ans_names <- if (use.names) names(x) else NULL
+        ans_mcols <- if (use.mcols) mcols(x) else NULL
+        new2("IRanges", start=ans_start,
+                        width=ans_width,
+                        NAMES=ans_names,
+                        elementMetadata=ans_mcols,
+                        check=FALSE)
+    }
+)
+
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### isEmpty() and isNormal()
@@ -129,11 +148,8 @@ setValidity2("NormalIRanges", .valid.NormalIRanges)
 ### Coercion.
 ###
 
-### Any Ranges object can be turned into an IRanges instance.
 setAs("Ranges", "IRanges",
-    function(from)
-        new2("IRanges", start=start(from), width=width(from),
-             NAMES=names(from), check=FALSE)
+    function(from) ranges(from, use.mcols=TRUE)
 )
 
 ### Helper function (not exported) used by the "coerce" methods defined in
@@ -161,7 +177,7 @@ setAs("logical", "NormalIRanges",
     function(from) .Call2("NormalIRanges_from_logical", from, PACKAGE="IRanges")
 )
 
-### coersion from integer
+### coercion from integer
 setAs("integer", "IRanges",
     function(from) .Call2("IRanges_from_integer", from, PACKAGE="IRanges")
 )
@@ -175,6 +191,43 @@ setAs("numeric", "IRanges", function(from) as(as.integer(from), "IRanges"))
 setAs("numeric", "NormalIRanges", 
     function(from) newNormalIRangesFromIRanges(as(as.integer(from), "IRanges")))
 
+### coercion from character
+.from_character_to_IRanges <- function(from)
+{
+    stopifnot(is.character(from))
+    if (anyNA(from))
+        stop(wmsg("converting a character vector to an IRanges object ",
+                  "does not support NAs"))
+    error_msg <- wmsg(
+        "The character vector to convert to an IRanges object must ",
+        "contain strings of the form \"start-end\" or \"start..end\", ",
+        "with end >= start - 1, or just \"pos\". For example: \"2501-2900\", ",
+        "\"2501..2900\", or \"740\"."
+    )
+    ## We want to split on the first occurence of  "-" that is preceeded by
+    ## a digit (ignoring and removing the spaces in between if any).
+    from <- sub("([[:digit:]])[[:space:]]*-", "\\1..", from)
+    split2 <- CharacterList(strsplit(from, "..", fixed=TRUE))
+    split2_eltNROWS <- elementNROWS(split2)
+    if (!all(split2_eltNROWS <= 2L))
+        stop(error_msg)
+    ans_start <- suppressWarnings(as.integer(phead(split2, n=1L)))
+    ans_end <- suppressWarnings(as.integer(ptail(split2, n=1L)))
+    if (anyNA(ans_start) || anyNA(ans_end))
+        stop(error_msg)
+    IRanges(ans_start, ans_end, names=names(from))
+}
+setAs("character", "IRanges", .from_character_to_IRanges)
+
+.from_factor_to_IRanges <- function(from)
+{
+    from <- setNames(as.character(from), names(from))
+    .from_character_to_IRanges(from)
+}
+setAs("factor", "IRanges", .from_factor_to_IRanges)
+
+setAs("ANY", "Ranges", function(from) as(from, "IRanges"))
+
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### Low-level setters for IRanges objects.
