@@ -41,9 +41,9 @@ setMethod("stack", "List",
             index <- .stack.ind(x, index.var)
             unlistsToVector <- is(value, "Vector")
             if (unlistsToVector) {
-                df <- cbind(index, S4Vectors:::ensureMcols(unname(value)))
+              df <- cbind(index, S4Vectors:::ensureMcols(unname(value)))
             } else {
-              df <- DataFrame(index, as(value, "DataFrame"))
+              df <- DataFrame(index, as(unname(value), "DataFrame"))
               colnames(df)[2] <- value.var
             }
             if (!is.null(name.var)) {
