@@ -16,25 +16,11 @@ setClass("NCList",
     )
 )
 
-setMethod("ranges", "NCList",
-    function(x, use.mcols=FALSE)
-    {
-        if (!isTRUEorFALSE(use.mcols))
-            stop("'use.mcols' must be TRUE or FALSE")
-        ans <- x@ranges
-        if (use.mcols)
-            mcols(ans) <- mcols(x)
-        ans
-    }
-)
-
-setMethod("length", "NCList", function(x) length(ranges(x)))
-setMethod("names", "NCList", function(x) names(ranges(x)))
-setMethod("start", "NCList", function(x, ...) start(ranges(x)))
-setMethod("end", "NCList", function(x, ...) end(ranges(x)))
-setMethod("width", "NCList", function(x) width(ranges(x)))
-
-setAs("NCList", "IRanges", function(from) ranges(from, use.mcols=TRUE))
+setMethod("length", "NCList", function(x) length(x@ranges))
+setMethod("names", "NCList", function(x) names(x@ranges))
+setMethod("start", "NCList", function(x, ...) start(x@ranges))
+setMethod("end", "NCList", function(x, ...) end(x@ranges))
+setMethod("width", "NCList", function(x) width(x@ranges))
 
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -161,7 +147,7 @@ print_NCList <- function(x)
 
 ### NOT exported.
 findOverlaps_NCList <- function(query, subject,
-             maxgap=0L, minoverlap=1L,
+             maxgap=-1L, minoverlap=0L,
              type=c("any", "start", "end", "within", "extend", "equal"),
              select=c("all", "first", "last", "arbitrary", "count"),
              circle.length=NA_integer_)
@@ -227,27 +213,31 @@ setMethod("parallelSlotNames", "NCLists",
 )
 
 ### TODO: Move rglist() generic from GenomicRanges to IRanges
-#setMethod("rglist", "NCLists", function(x, ...) x@ranges)
+#setMethod("rglist", "NCLists", function(x, ...) x@rglist)
 
 setMethod("ranges", "NCLists",
-    function(x, use.mcols=FALSE)
+    function(x, use.names=TRUE, use.mcols=FALSE)
     {
+        if (!isTRUEorFALSE(use.names))
+            stop("'use.names' must be TRUE or FALSE")
         if (!isTRUEorFALSE(use.mcols))
             stop("'use.mcols' must be TRUE or FALSE")
         ans <- x@rglist
+        if (!use.names)
+            names(ans) <- NULL
         if (use.mcols)
             mcols(ans) <- mcols(x)
         ans
     }
 )
 
-setMethod("length", "NCLists", function(x) length(ranges(x)))
-setMethod("names", "NCLists", function(x) names(ranges(x)))
-setMethod("start", "NCLists", function(x, ...) start(ranges(x)))
-setMethod("end", "NCLists", function(x, ...) end(ranges(x)))
-setMethod("width", "NCLists", function(x) width(ranges(x)))
+setMethod("length", "NCLists", function(x) length(x@rglist))
+setMethod("names", "NCLists", function(x) names(x@rglist))
+setMethod("start", "NCLists", function(x, ...) start(x@rglist))
+setMethod("end", "NCLists", function(x, ...) end(x@rglist))
+setMethod("width", "NCLists", function(x) width(x@rglist))
 
-setMethod("elementNROWS", "NCLists", function(x) elementNROWS(ranges(x)))
+setMethod("elementNROWS", "NCLists", function(x) elementNROWS(x@rglist))
 setMethod("getListElement", "NCLists",
     function (x, i, exact=TRUE)
     {
@@ -316,7 +306,7 @@ NCList_find_overlaps_in_groups <- function(
              q, q_space, q_groups,
              s, s_space, s_groups,
              nclists, nclist_is_q,
-             maxgap=0L, minoverlap=1L,
+             maxgap=-1L, minoverlap=0L,
              type=c("any", "start", "end", "within", "extend", "equal"),
              select=c("all", "first", "last", "arbitrary", "count"),
              circle.length)
@@ -400,7 +390,7 @@ NCList_find_overlaps_in_groups <- function(
 ###   (b) integer vectors if 'select' is not "all". In that case the list is
 ###       parallel to and has the same shape as 'query'.
 findOverlaps_NCLists <- function(query, subject,
-             maxgap=0L, minoverlap=1L,
+             maxgap=-1L, minoverlap=0L,
              type=c("any", "start", "end", "within", "extend", "equal"),
              select=c("all", "first", "last", "arbitrary", "count"),
              circle.length=NA_integer_)
