@@ -67,22 +67,6 @@ setMethod("rev", "Vector",
 setMethod("rep", "Vector", function(x, ...)
           x[rep(seq_len(length(x)), ...)])
 
-setMethod("rep.int", "Vector",
-    function(x, times)
-    {
-        x_len <- length(x)
-        times_len <- length(times)
-        if (times_len == 1L) {
-            i <- IRanges(rep.int(1L, times), rep.int(x_len, times))
-        } else if (times_len == x_len) {
-            i <- Rle(seq_len(x_len), times)
-        } else {
-            stop("invalid 'times' value")
-        }
-        x[i]
-    }
-)
-
 setMethod("subset", "Vector",
           function(x, subset, select, drop = FALSE, ...) {
             i <- S4Vectors:::evalqForSubset(subset, x, ...)
@@ -99,6 +83,7 @@ setMethod("subset", "Vector",
 
 setGeneric("mstack", function(..., .index.var = "name")
            standardGeneric("mstack"), signature = "...")
+BiocGenerics:::apply_hotfix73465(getGeneric("mstack"))
 
 setMethod("mstack", "Vector", function(..., .index.var = "name") {
   if (!isSingleString(.index.var))
