@@ -58,7 +58,7 @@ setMethod("process_self_hits", "SortedByQueryHitsList",
 ###
 
 setGeneric("findOverlaps", signature=c("query", "subject"),
-    function(query, subject, maxgap=0L, minoverlap=1L,
+    function(query, subject, maxgap=-1L, minoverlap=0L,
              type=c("any", "start", "end", "within", "equal"),
              select=c("all", "first", "last", "arbitrary"),
              ...)
@@ -66,7 +66,7 @@ setGeneric("findOverlaps", signature=c("query", "subject"),
 )
 
 findOverlaps_Ranges <- function(query, subject,
-             maxgap=0L, minoverlap=1L,
+             maxgap=-1L, minoverlap=0L,
              type=c("any", "start", "end", "within", "equal"),
              select=c("all", "first", "last", "arbitrary"))
 {
@@ -80,7 +80,7 @@ findOverlaps_Ranges <- function(query, subject,
 setMethod("findOverlaps", c("Ranges", "Ranges"), findOverlaps_Ranges)
 
 setMethod("findOverlaps", c("Vector", "missing"),
-    function(query, subject, maxgap=0L, minoverlap=1L,
+    function(query, subject, maxgap=-1L, minoverlap=0L,
              type=c("any", "start", "end", "within", "equal"),
              select=c("all", "first", "last", "arbitrary"),
              ...,
@@ -96,7 +96,7 @@ setMethod("findOverlaps", c("Vector", "missing"),
 )
 
 setMethod("findOverlaps", c("integer", "Ranges"),
-    function(query, subject, maxgap=0L, minoverlap=1L,
+    function(query, subject, maxgap=-1L, minoverlap=0L,
              type=c("any", "start", "end", "within", "equal"),
              select=c("all", "first", "last", "arbitrary"))
     {
@@ -107,7 +107,7 @@ setMethod("findOverlaps", c("integer", "Ranges"),
 )
 
 setMethod("findOverlaps", c("Views", "Views"),
-    function(query, subject, maxgap=0L, minoverlap=1L,
+    function(query, subject, maxgap=-1L, minoverlap=0L,
              type=c("any", "start", "end", "within", "equal"),
              select=c("all", "first", "last", "arbitrary"))
     {
@@ -118,7 +118,7 @@ setMethod("findOverlaps", c("Views", "Views"),
 )
 
 setMethod("findOverlaps", c("Views", "Vector"),
-    function(query, subject, maxgap=0L, minoverlap=1L,
+    function(query, subject, maxgap=-1L, minoverlap=0L,
              type=c("any", "start", "end", "within", "equal"),
              select=c("all", "first", "last", "arbitrary"))
     {
@@ -129,7 +129,7 @@ setMethod("findOverlaps", c("Views", "Vector"),
 )
 
 setMethod("findOverlaps", c("Vector", "Views"),
-    function(query, subject, maxgap=0L, minoverlap=1L,
+    function(query, subject, maxgap=-1L, minoverlap=0L,
              type=c("any", "start", "end", "within", "equal"),
              select=c("all", "first", "last", "arbitrary"))
     {
@@ -141,7 +141,7 @@ setMethod("findOverlaps", c("Vector", "Views"),
 
 # might consider making this the following:
 # setMethod("findOverlaps", c("RangesList", "RangesList"),
-#           function(query, subject, maxgap = 0L, minoverlap = 1L,
+#           function(query, subject, maxgap = -1L, minoverlap = 0L,
 #                    type = c("any", "start", "end", "within", "equal"),
 #                    select = c("all", "first", "last", "arbitrary"),
 #                    drop = FALSE)
@@ -153,7 +153,7 @@ setMethod("findOverlaps", c("Vector", "Views"),
 #   )
 
 setMethod("findOverlaps", c("RangesList", "RangesList"),
-          function(query, subject, maxgap = 0L, minoverlap = 1L,
+          function(query, subject, maxgap = -1L, minoverlap = 0L,
                    type = c("any", "start", "end", "within", "equal"),
                    select = c("all", "first", "last", "arbitrary"),
                    drop = FALSE)
@@ -198,9 +198,8 @@ setMethod("findOverlaps", c("RangesList", "RangesList"),
             ans
           })
 
-
 setMethod("findOverlaps", c("ViewsList", "ViewsList"),
-    function(query, subject, maxgap=0L, minoverlap=1L,
+    function(query, subject, maxgap=-1L, minoverlap=0L,
              type=c("any", "start", "end", "within", "equal"),
              select=c("all", "first", "last", "arbitrary"),
              drop=FALSE)
@@ -213,7 +212,7 @@ setMethod("findOverlaps", c("ViewsList", "ViewsList"),
 )
 
 setMethod("findOverlaps", c("ViewsList", "Vector"),
-    function(query, subject, maxgap=0L, minoverlap=1L,
+    function(query, subject, maxgap=-1L, minoverlap=0L,
              type=c("any", "start", "end", "within", "equal"),
              select=c("all", "first", "last", "arbitrary"),
              drop=FALSE)
@@ -226,7 +225,7 @@ setMethod("findOverlaps", c("ViewsList", "Vector"),
 )
 
 setMethod("findOverlaps", c("Vector", "ViewsList"),
-    function(query, subject, maxgap=0L, minoverlap=1L,
+    function(query, subject, maxgap=-1L, minoverlap=0L,
              type=c("any", "start", "end", "within", "equal"),
              select=c("all", "first", "last", "arbitrary"),
              drop=FALSE)
@@ -239,7 +238,7 @@ setMethod("findOverlaps", c("Vector", "ViewsList"),
 )
 
 setMethod("findOverlaps", c("RangedData", "RangedData"),
-          function(query, subject, maxgap = 0L, minoverlap = 1L,
+          function(query, subject, maxgap = -1L, minoverlap = 0L,
                    type = c("any", "start", "end", "within", "equal"),
                    select = c("all", "first", "last", "arbitrary"),
                    drop = FALSE)
@@ -251,7 +250,7 @@ setMethod("findOverlaps", c("RangedData", "RangedData"),
           })
 
 setMethod("findOverlaps", c("RangedData", "RangesList"),
-          function(query, subject, maxgap = 0L, minoverlap = 1L,
+          function(query, subject, maxgap = -1L, minoverlap = 0L,
                    type = c("any", "start", "end", "within", "equal"),
                    select = c("all", "first", "last", "arbitrary"),
                    drop = FALSE)
@@ -263,7 +262,7 @@ setMethod("findOverlaps", c("RangedData", "RangesList"),
           })
 
 setMethod("findOverlaps", c("RangesList", "RangedData"),
-          function(query, subject, maxgap = 0L, minoverlap = 1L,
+          function(query, subject, maxgap = -1L, minoverlap = 0L,
                    type = c("any", "start", "end", "within", "equal"),
                    select = c("all", "first", "last", "arbitrary"),
                    drop = FALSE)
@@ -275,8 +274,7 @@ setMethod("findOverlaps", c("RangesList", "RangedData"),
           })
 
 setMethod("findOverlaps", c("Pairs", "missing"),
-          function (query, subject, maxgap = 0L,
-                    minoverlap = 1L,
+          function (query, subject, maxgap = -1L, minoverlap = 0L,
                     type = c("any",  "start", "end", "within", "equal"),
                     select = c("all", "first", "last", "arbitrary"), ...) {
               findOverlaps(zipup(query), maxgap=maxgap,
@@ -284,8 +282,7 @@ setMethod("findOverlaps", c("Pairs", "missing"),
           })
 
 setMethod("findOverlaps", c("Pairs", "ANY"),
-          function (query, subject, maxgap = 0L,
-                    minoverlap = 1L,
+          function (query, subject, maxgap = -1L, minoverlap = 0L,
                     type = c("any",  "start", "end", "within", "equal"),
                     select = c("all", "first", "last", "arbitrary"), ...) {
               findOverlaps(zipup(query), subject, maxgap=maxgap,
@@ -293,8 +290,7 @@ setMethod("findOverlaps", c("Pairs", "ANY"),
           })
 
 setMethod("findOverlaps", c("ANY", "Pairs"),
-          function (query, subject, maxgap = 0L,
-                    minoverlap = 1L,
+          function (query, subject, maxgap = -1L, minoverlap = 0L,
                     type = c("any",  "start", "end", "within", "equal"),
                     select = c("all", "first", "last", "arbitrary"), ...) {
               findOverlaps(query, zipup(subject), maxgap=maxgap,
@@ -302,8 +298,7 @@ setMethod("findOverlaps", c("ANY", "Pairs"),
           })
 
 setMethod("findOverlaps", c("Pairs", "Pairs"),
-          function (query, subject, maxgap = 0L,
-                    minoverlap = 1L,
+          function (query, subject, maxgap = -1L, minoverlap = 0L,
                     type = c("any",  "start", "end", "within", "equal"),
                     select = c("all", "first", "last", "arbitrary"), ...) {
               findOverlaps(zipup(query), zipup(subject),
@@ -315,27 +310,27 @@ setMethod("findOverlaps", c("Pairs", "Pairs"),
 ### countOverlaps()
 ###
 
-setGeneric("countOverlaps", signature = c("query", "subject"),
-    function(query, subject, maxgap = 0L, minoverlap = 1L,
-             type = c("any", "start", "end", "within", "equal"),
+setGeneric("countOverlaps", signature=c("query", "subject"),
+    function(query, subject, maxgap=-1L, minoverlap=0L,
+             type=c("any", "start", "end", "within", "equal"),
              ...)
         standardGeneric("countOverlaps")
 )
 
 .countOverlaps_default <-
-    function(query, subject, maxgap=0L, minoverlap=1L,
+    function(query, subject, maxgap=-1L, minoverlap=0L,
              type=c("any", "start", "end", "within", "equal"),
              ...)
 {
     type <- match.arg(type)
     if (missing(subject)) {
         hits <- findOverlaps(query,
-                             maxgap=maxgap, minoverlap=minoverlap, 
+                             maxgap=maxgap, minoverlap=minoverlap,
                              type=type,
                              ...)
     } else {
         hits <- findOverlaps(query, subject,
-                             maxgap=maxgap, minoverlap=minoverlap, 
+                             maxgap=maxgap, minoverlap=minoverlap,
                              type=type,
                              ...)
     }
@@ -348,7 +343,7 @@ setMethod("countOverlaps", c("Vector", "Vector"), .countOverlaps_default)
 setMethod("countOverlaps", c("Vector", "missing"), .countOverlaps_default)
 
 countOverlaps_Ranges <- function(query, subject,
-              maxgap=0L, minoverlap=1L,
+              maxgap=-1L, minoverlap=0L,
               type=c("any", "start", "end", "within", "equal"))
 {
     type <- match.arg(type)
@@ -362,7 +357,7 @@ countOverlaps_Ranges <- function(query, subject,
 setMethod("countOverlaps", c("Ranges", "Ranges"), countOverlaps_Ranges)
 
 setMethod("countOverlaps", c("RangesList", "RangesList"),
-          function(query, subject, maxgap = 0L, minoverlap = 1L,
+          function(query, subject, maxgap=-1L, minoverlap=0L,
                    type = c("any", "start", "end", "within", "equal"))
           {
               IntegerList(mapply(countOverlaps, query, subject,
@@ -373,7 +368,7 @@ setMethod("countOverlaps", c("RangesList", "RangesList"),
           })
 
 setMethod("countOverlaps", c("ViewsList", "ViewsList"),
-    function(query, subject, maxgap=0L, minoverlap=1L,
+    function(query, subject, maxgap=-1L, minoverlap=0L,
              type=c("any", "start", "end", "within", "equal"))
     {
          countOverlaps(ranges(query), ranges(subject),
@@ -383,7 +378,7 @@ setMethod("countOverlaps", c("ViewsList", "ViewsList"),
 )
 
 setMethod("countOverlaps", c("ViewsList", "Vector"),
-    function(query, subject, maxgap=0L, minoverlap=1L,
+    function(query, subject, maxgap=-1L, minoverlap=0L,
              type=c("any", "start", "end", "within", "equal"))
     {
          countOverlaps(ranges(query), subject,
@@ -393,7 +388,7 @@ setMethod("countOverlaps", c("ViewsList", "Vector"),
 )
 
 setMethod("countOverlaps", c("Vector", "ViewsList"),
-    function(query, subject, maxgap=0L, minoverlap=1L,
+    function(query, subject, maxgap=-1L, minoverlap=0L,
              type=c("any", "start", "end", "within", "equal"))
     {
          countOverlaps(query, ranges(subject),
@@ -403,21 +398,21 @@ setMethod("countOverlaps", c("Vector", "ViewsList"),
 )
 
 setMethod("countOverlaps", c("RangedData", "RangedData"),
-          function(query, subject, maxgap = 0L, minoverlap = 1L,
+          function(query, subject, maxgap = -1L, minoverlap = 0L,
                    type = c("any", "start", "end", "within", "equal"))
           {
               countOverlaps(ranges(query), ranges(subject), maxgap = maxgap,
                             minoverlap = minoverlap, type = match.arg(type))
           })
 setMethod("countOverlaps", c("RangedData", "RangesList"),
-          function(query, subject, maxgap = 0L, minoverlap = 1L,
+          function(query, subject, maxgap = -1L, minoverlap = 0L,
                    type = c("any", "start", "end", "within", "equal"))
           {
               countOverlaps(ranges(query), subject, maxgap = maxgap,
                             minoverlap = minoverlap, type = match.arg(type))
           })
 setMethod("countOverlaps", c("RangesList", "RangedData"),
-          function(query, subject, maxgap = 0L, minoverlap = 1L,
+          function(query, subject, maxgap = -1L, minoverlap = 0L,
                    type = c("any", "start", "end", "within", "equal"))
           {
               countOverlaps(query, ranges(subject), maxgap = maxgap,
@@ -429,16 +424,16 @@ setMethod("countOverlaps", c("RangesList", "RangedData"),
 ### overlapsAny()
 ###
 
-### Same args and signature as countOverlaps() and subsetByOverlaps().
+### Same args and signature as countOverlaps().
 setGeneric("overlapsAny", signature=c("query", "subject"),
-    function(query, subject, maxgap=0L, minoverlap=1L,
+    function(query, subject, maxgap=-1L, minoverlap=0L,
              type=c("any", "start", "end", "within", "equal"),
              ...)
         standardGeneric("overlapsAny")
 )
 
 .overlapsAny_default <-
-    function(query, subject, maxgap=0L, minoverlap=1L,
+    function(query, subject, maxgap=-1L, minoverlap=0L,
              type=c("any", "start", "end", "within", "equal"),
              ...)
 {
@@ -461,7 +456,7 @@ setMethod("overlapsAny", c("Vector", "Vector"), .overlapsAny_default)
 setMethod("overlapsAny", c("Vector", "missing"), .overlapsAny_default)
 
 setMethod("overlapsAny", c("RangesList", "RangesList"),
-    function(query, subject, maxgap=0L, minoverlap=1L,
+    function(query, subject, maxgap=-1L, minoverlap=0L,
              type=c("any", "start", "end", "within", "equal"),
              ...)
     {
@@ -488,7 +483,7 @@ setMethod("overlapsAny", c("RangesList", "RangesList"),
 )
 
 setMethod("overlapsAny", c("ViewsList", "ViewsList"),
-    function(query, subject, maxgap=0L, minoverlap=1L,
+    function(query, subject, maxgap=-1L, minoverlap=0L,
              type=c("any", "start", "end", "within", "equal"),
              ...)
     {
@@ -500,7 +495,7 @@ setMethod("overlapsAny", c("ViewsList", "ViewsList"),
 )
 
 setMethod("overlapsAny", c("ViewsList", "Vector"),
-    function(query, subject, maxgap=0L, minoverlap=1L,
+    function(query, subject, maxgap=-1L, minoverlap=0L,
              type=c("any", "start", "end", "within", "equal"),
              ...)
     {
@@ -512,7 +507,7 @@ setMethod("overlapsAny", c("ViewsList", "Vector"),
 )
 
 setMethod("overlapsAny", c("Vector", "ViewsList"),
-    function(query, subject, maxgap=0L, minoverlap=1L,
+    function(query, subject, maxgap=-1L, minoverlap=0L,
              type=c("any", "start", "end", "within", "equal"),
              ...)
     {
@@ -523,11 +518,20 @@ setMethod("overlapsAny", c("Vector", "ViewsList"),
     }
 )
 
+.overlapsAny_RangedData_deprecation_msg <- c(
+    "The \"overlapsAny\" methods for RangedData objects are deprecated ",
+    "and won't be replaced. Please migrate your code to use GRanges or ",
+    "GRangesList objects instead. RangedData objects will be deprecated ",
+    "soon (their use has been discouraged since BioC 2.12, that is, since ",
+    "2014). See IMPORTANT NOTE in ?RangedData"
+)
+
 setMethod("overlapsAny", c("RangedData", "RangedData"),
-    function(query, subject, maxgap=0L, minoverlap=1L,
+    function(query, subject, maxgap=-1L, minoverlap=0L,
              type=c("any", "start", "end", "within", "equal"),
              ...)
     {
+        .Deprecated(msg=wmsg(.overlapsAny_RangedData_deprecation_msg))
         overlapsAny(ranges(query), ranges(subject),
                     maxgap=maxgap, minoverlap=minoverlap,
                     type=match.arg(type),
@@ -536,10 +540,11 @@ setMethod("overlapsAny", c("RangedData", "RangedData"),
 )
 
 setMethod("overlapsAny", c("RangedData", "RangesList"),
-    function(query, subject, maxgap=0L, minoverlap=1L,
+    function(query, subject, maxgap=-1L, minoverlap=0L,
              type=c("any", "start", "end", "within", "equal"),
              ...)
     {
+        .Deprecated(msg=wmsg(.overlapsAny_RangedData_deprecation_msg))
         overlapsAny(ranges(query), subject,
                     maxgap=maxgap, minoverlap=minoverlap,
                     type=match.arg(type),
@@ -548,10 +553,11 @@ setMethod("overlapsAny", c("RangedData", "RangesList"),
 )
 
 setMethod("overlapsAny", c("RangesList", "RangedData"),
-    function(query, subject, maxgap=0L, minoverlap=1L,
+    function(query, subject, maxgap=-1L, minoverlap=0L,
              type=c("any", "start", "end", "within", "equal"),
              ...)
     {
+        .Deprecated(msg=.wmsg(overlapsAny_RangedData_deprecation_msg))
         overlapsAny(query, ranges(subject),
                     maxgap=maxgap, minoverlap=minoverlap,
                     type=match.arg(type),
@@ -566,6 +572,194 @@ setMethod("overlapsAny", c("RangesList", "RangedData"),
 `%outside%` <- function(query, subject) !overlapsAny(query, subject)
 
 
+### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+### subsetByOverlaps()
+###
+
+### First 2 arguments are 'x' and 'ranges' like for the
+### transcriptsByOverlaps(), exonsByOverlaps(), and cdsByOverlaps() functions
+### from the GenomicFeatures package and the snpsByOverlaps() function from
+### the BSgenome package.
+setGeneric("subsetByOverlaps", signature=c("x", "ranges"),
+    function(x, ranges, maxgap=-1L, minoverlap=0L,
+             type=c("any", "start", "end", "within", "equal"),
+             invert=FALSE, ...)
+        standardGeneric("subsetByOverlaps")
+)
+
+setMethod("subsetByOverlaps", c("Vector", "Vector"),
+    function(x, ranges, maxgap=-1L, minoverlap=0L,
+             type=c("any", "start", "end", "within", "equal"), invert=FALSE,
+             ...)
+    {
+        ov_any <- overlapsAny(x, ranges,
+                              maxgap=maxgap, minoverlap=minoverlap,
+                              type=match.arg(type),
+                              ...)
+        if (invert)
+            ov_any <- !ov_any
+        x[ov_any]
+    }
+)
+
+.subsetByOverlaps_RangedData_deprecation_msg <- c(
+    "The \"subsetByOverlaps\" methods for RangedData objects are deprecated ",
+    "and won't be replaced. Please migrate your code to use GRanges or ",
+    "GRangesList objects instead. RangedData objects will be deprecated ",
+    "soon (their use has been discouraged since BioC 2.12, that is, since ",
+    "2014). See IMPORTANT NOTE in ?RangedData"
+)
+
+setMethod("subsetByOverlaps", c("RangedData", "RangedData"),
+          function(x, ranges, maxgap = -1L, minoverlap = 0L,
+                   type = c("any", "start", "end", "within", "equal"),
+                   invert = FALSE)
+          {
+            .Deprecated(msg=wmsg(.subsetByOverlaps_RangedData_deprecation_msg))
+            ov_any <- unlist(!is.na(findOverlaps(ranges(x), ranges(ranges),
+                                                 maxgap = maxgap,
+                                                 minoverlap = minoverlap,
+                                                 type = match.arg(type),
+                                                 select = "arbitrary")),
+                             use.names=FALSE)
+            if (invert)
+                ov_any <- !ov_any
+            x[ov_any]
+          })
+
+setMethod("subsetByOverlaps", c("RangedData", "RangesList"),
+          function(x, ranges, maxgap = -1L, minoverlap = 0L,
+                   type = c("any", "start", "end", "within", "equal"),
+                   invert = FALSE)
+          {
+            .Deprecated(msg=wmsg(.subsetByOverlaps_RangedData_deprecation_msg))
+            ov_any <- unlist(!is.na(findOverlaps(ranges(x), ranges,
+                                                 maxgap = maxgap,
+                                                 minoverlap = minoverlap,
+                                                 type = match.arg(type),
+                                                 select = "arbitrary")),
+                             use.names=FALSE)
+            if (invert)
+                ov_any <- !ov_any
+            x[ov_any]
+          })
+
+setMethod("subsetByOverlaps", c("RangesList", "RangedData"),
+          function(x, ranges, maxgap = -1L, minoverlap = 0L,
+                   type = c("any", "start", "end", "within", "equal"),
+                   invert = FALSE)
+          {
+            .Deprecated(msg=wmsg(.subsetByOverlaps_RangedData_deprecation_msg))
+            ov_any <- !is.na(findOverlaps(x, ranges(ranges),
+                                          maxgap = maxgap,
+                                          minoverlap = minoverlap,
+                                          type = match.arg(type),
+                                          select = "arbitrary"))
+            if (invert)
+                ov_any <- !ov_any
+            x[ov_any]
+          })
+
+
+### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+### overlapsRanges()
+###
+### Extracts the actual regions of intersection between the overlapping ranges.
+###
+
+setGeneric("overlapsRanges", signature=c("query", "subject"),
+    function(query, subject, hits=NULL, ...) standardGeneric("overlapsRanges")
+)
+
+setMethod("overlapsRanges", c("Ranges", "Ranges"),
+    function(query, subject, hits=NULL, ...)
+    {
+        if (is.null(hits)) {
+            hits <- findOverlaps(query, subject, ...)
+        } else {
+            if (!is(hits, "Hits"))
+                stop("'hits' must be a Hits object")
+            if (length(list(...)) != 0L)
+                stop(wmsg("Extra arguments are only accepted when the 'hits' ",
+                          "argument is not supplied, in which case they are ",
+                          "passed to the internal call to findOverlaps(). ",
+                          "See ?overlapsRanges for more information."))
+            if (queryLength(hits) != length(query) ||
+                subjectLength(hits) != length(subject))
+                stop("'hits' is not compatible with 'query' and 'subject'")
+        }
+        ### Could be replaced by 1-liner:
+        ###   pintersect(query[queryHits(hits)], subject[subjectHits(hits)])
+        ### but will fail if 'query' or 'subject' is a kind of Ranges object
+        ### that cannot be subsetted (e.g. Partitioning object).
+        m <- as.matrix(hits)
+        qstart <- start(query)[m[,1L]]
+        qend <- end(query)[m[,1L]]
+        sstart <- start(subject)[m[,2L]]
+        send <- end(subject)[m[,2L]]
+        IRanges(pmax.int(qstart, sstart), pmin.int(send, qend))
+    }
+)
+
+setMethod("overlapsRanges", c("RangesList", "RangesList"),
+    function(query, subject, hits=NULL, ...)
+    {
+        if (is.null(hits)) {
+            hits <- findOverlaps(query, subject, ...)
+        } else {
+            if (!is(hits, "HitsList"))
+                stop("'hits' must be a HitsList object")
+            if (length(list(...)) != 0L)
+                stop(wmsg("Extra arguments are only accepted when the 'hits' ",
+                          "argument is not supplied, in which case they are ",
+                          "passed to the internal call to findOverlaps(). ",
+                          "See ?overlapsRanges for more information."))
+            if (length(hits) != length(query) ||
+                length(hits) != length(subject))
+                stop("'query', 'subject', and 'hits' must have the same length")
+        }
+        queries <- as.list(query, use.names = FALSE)
+        subjects <- as.list(subject, use.names = FALSE)
+        els <- as.list(hits, use.names = FALSE)
+        ans <- do.call(RangesList, lapply(seq_len(length(hits)), function(i) {
+          overlapsRanges(queries[[i]], subjects[[i]], els[[i]])
+        }))
+        names(ans) <- names(hits)
+        ans
+    }
+)
+
+setMethod("ranges", "Hits", function(x, use.names=TRUE, use.mcols=FALSE,
+                                        query, subject)
+{
+    msg <- c("\"ranges\" method for Hits objects is deprecated. ",
+             "Please use overlapsRanges() instead.")
+    .Deprecated(msg=wmsg(msg))
+    query_is_missing <- missing(query)
+    subject_is_missing <- missing(subject)
+    if (query_is_missing || subject_is_missing) {
+        query <- if (subject_is_missing) use.names else use.mcols
+        subject <- if (query_is_missing) use.mcols else use.names
+    }
+    overlapsRanges(query, subject, x)
+})
+
+setMethod("ranges", "HitsList", function(x, use.names=TRUE, use.mcols=FALSE,
+                                            query, subject)
+{
+    msg <- c("\"ranges\" method for HitsList objects is deprecated. ",
+             "Please use overlapsRanges() instead.")
+    .Deprecated(msg=wmsg(msg))
+    query_is_missing <- missing(query)
+    subject_is_missing <- missing(subject)
+    if (query_is_missing || subject_is_missing) {
+        query <- if (subject_is_missing) use.names else use.mcols
+        subject <- if (query_is_missing) use.mcols else use.names
+    }
+    overlapsRanges(query, subject, x)
+})
+
+
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### poverlaps()
 ###
@@ -633,71 +827,6 @@ setMethod("poverlaps", c("Ranges", "integer"),
 `%pwithin%` <- function(query, subject) poverlaps(query, subject, type="within")
 `%poutside%` <- function(query, subject) !poverlaps(query, subject)
 
-### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### subsetByOverlaps()
-###
-
-setGeneric("subsetByOverlaps", signature=c("query", "subject"),
-    function(query, subject, maxgap=0L, minoverlap=1L,
-             type=c("any", "start", "end", "within", "equal"),
-             invert=FALSE, ...)
-        standardGeneric("subsetByOverlaps")
-)
-
-setMethod("subsetByOverlaps", c("Vector", "Vector"),
-    function(query, subject, maxgap=0L, minoverlap=1L,
-             type=c("any", "start", "end", "within", "equal"), invert=FALSE,
-             ...)
-    {
-        o <- overlapsAny(query, subject,
-                         maxgap=maxgap, minoverlap=minoverlap,
-                         type=match.arg(type),
-                         ...)
-        if (invert) query[!o] else query[o]
-    }
-)
-
-setMethod("subsetByOverlaps", c("RangedData", "RangedData"),
-          function(query, subject, maxgap = 0L, minoverlap = 1L,
-                   type = c("any", "start", "end", "within", "equal"),
-                   invert = FALSE)
-          {
-              o <- unlist(!is.na(findOverlaps(ranges(query), ranges(subject),
-                                              maxgap = maxgap,
-                                              minoverlap = minoverlap,
-                                              type = match.arg(type),
-                                              select = "arbitrary")),
-                          use.names=FALSE)
-              if (invert) query[!o,] else query[o,]
-          })
-
-setMethod("subsetByOverlaps", c("RangedData", "RangesList"),
-          function(query, subject, maxgap = 0L, minoverlap = 1L,
-                   type = c("any", "start", "end", "within", "equal"),
-                   invert = FALSE)
-          {
-              o <- unlist(!is.na(findOverlaps(ranges(query), subject,
-                                              maxgap = maxgap,
-                                              minoverlap = minoverlap,
-                                              type = match.arg(type),
-                                              select = "arbitrary")),
-                          use.names=FALSE)
-              if (invert) query[!o,] else query[o,]
-          })
-
-setMethod("subsetByOverlaps", c("RangesList", "RangedData"),
-          function(query, subject, maxgap = 0L, minoverlap = 1L,
-                   type = c("any", "start", "end", "within", "equal"),
-                   invert = FALSE)
-          {
-              o <- !is.na(findOverlaps(query, ranges(subject),
-                                       maxgap = maxgap,
-                                       minoverlap = minoverlap,
-                                       type = match.arg(type),
-                                       select = "arbitrary"))
-              if (invert) query[!o] else query[o]
-          })
-
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### Merge two sets of ranges by overlap into a DataFrame
@@ -712,40 +841,6 @@ mergeByOverlaps <- function(query, subject, ...) {
   cbind(query_df, subject_df)
 }
 
-### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-### "ranges" methods for Hits and HitsList objects
-###
-
-### Extracts the actual regions of intersection between the overlapping ranges.
-### Not much value. Could be replaced by 1-liner:
-###   pintersect(query[queryHits(x)], subject[subjectHits(x)])
-setMethod("ranges", "Hits", function(x, query, subject) {
-  if (!is(query, "Ranges") || length(query) != queryLength(x))
-    stop("'query' must be a Ranges of length equal to number of queries")
-  if (!is(subject, "Ranges") || length(subject) != subjectLength(x))
-    stop("'subject' must be a Ranges of length equal to number of subjects")
-  m <- as.matrix(x)
-  qstart <- start(query)[m[,1L]]
-  qend <- end(query)[m[,1L]]
-  sstart <- start(subject)[m[,2L]]
-  send <- end(subject)[m[,2L]]
-  IRanges(pmax.int(qstart, sstart), pmin.int(send, qend))
-})
-
-setMethod("ranges", "HitsList", function(x, query, subject) {
-  if (!is(query, "RangesList") || length(query) != length(x))
-    stop("'query' must be a RangesList of length equal to that of 'x'")
-  if (!is(subject, "RangesList") || length(subject) != length(x))
-    stop("'subject' must be a RangesList of length equal to that of 'x'")
-  els <- as.list(x, use.names = FALSE)
-  queries <- as.list(query, use.names = FALSE)
-  subjects <- as.list(subject, use.names = FALSE)
-  ans <- do.call(RangesList, lapply(seq_len(length(x)), function(i) {
-    ranges(els[[i]], queries[[i]], subjects[[i]])
-  }))
-  names(ans) <- names(x)
-  ans
-})
 
 ### - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ### Convenience for dereferencing overlap hits to a Pairs
