@@ -62,6 +62,15 @@ setMethod("range", "Ranges",
     }
 )
 
+### Overwrite above method with optimized method for IPos objects.
+### Like the above method, return an IRanges instance.
+setMethod("range", "IPos",
+    function(x, ..., with.revmap=FALSE, ignore.strand=FALSE, na.rm=FALSE)
+        callGeneric(stitch_IPos(x), ...,
+                    with.revmap=with.revmap, ignore.strand=ignore.strand,
+                    na.rm=na.rm)
+)
+
 setMethod("range", "RangesList",
     function(x, ..., with.revmap=FALSE, na.rm=FALSE)
     {
@@ -112,7 +121,16 @@ setMethod("range", "CompressedIRangesList",
     }
 )
 
+.range_RangedData_deprecation_msg <- c(
+    "The \"range\" method for RangedData objects is deprecated ",
+    "and won't be replaced. Please migrate your code to use GRanges or ",
+    "GRangesList objects instead. RangedData objects will be deprecated ",
+    "soon (their use has been discouraged since BioC 2.12, that is, since ",
+    "2014). See IMPORTANT NOTE in ?RangedData"
+)
+
 setMethod("range", "RangedData", function(x, ..., na.rm) {
+  .Deprecated(msg=wmsg(.range_RangedData_deprecation_msg))
   args <- list(x, ...)
   rangeLists <- lapply(args, ranges)
   do.call(range, rangeLists)
@@ -375,6 +393,10 @@ setGeneric("disjoin", function(x, ...) standardGeneric("disjoin"))
 
 ### Always return an IRanges *instance* whatever Ranges derivative the input
 ### is, so does NOT act like an endomorphism in general.
+### FIXME: Does not properly handle zero-width ranges at the moment e.g.
+### disjoin(IRanges(c(1, 11, 13), width=c(2, 5, 0)) returns
+### IRanges(c(1, 11, 13), width=c(2, 2, 3)) when it should return
+### IRanges(c(1, 11, 13, 13), width=c(2, 2, 0, 3)).
 setMethod("disjoin", "Ranges",
     function(x, with.revmap=FALSE)
     {
@@ -390,7 +412,7 @@ setMethod("disjoin", "Ranges",
         adj <- new2("IRanges", start=adj_start,
                                width=adj_width,
                                check=FALSE)
-        adj <- subsetByOverlaps(adj, x)
+        adj <- subsetByOverlaps(adj, x, minoverlap=1L)
         if (with.revmap)
              mcols(adj)$revmap <- as(sort(findOverlaps(adj, x)),"List")
         adj
@@ -475,6 +497,9 @@ setMethod("isDisjoint", "Ranges",
     }
 )
 
+### Overwrite above method with optimized method for IPos objects.
+setMethod("isDisjoint", "IPos", function(x) callGeneric(stitch_IPos(x)))
+
 setMethod("isDisjoint", "NormalIRanges", function(x) TRUE)
 
 setMethod("isDisjoint", "RangesList",
