@@ -64,6 +64,32 @@ setMethod("shift", "Ranges",
     }
 )
 
+### Overwrite above method with optimized method for IPos objects.
+### An IPos object cannot hold names so the 'use.names' arg has no effect.
+### NOTE: We only support shifting by a single value at the moment!
+setMethod("shift", "IPos",
+    function(x, shift=0L, use.names=TRUE)
+    {
+        if (!is.numeric(shift))
+            stop("'shift' must be a numeric vector")
+        if (!is.integer(shift))
+            shift <- as.integer(shift)
+        if (length(shift) != 1L) {
+            if (length(shift) != length(x))
+                stop("'shift' must be a single number or have the ",
+                     "length of 'x' when shifting an IPos object")
+            if (length(shift) != 0L) {
+                if (!isConstant(shift))
+                    stop("'shift' must be constant when shifting ",
+                         "an IPos object")
+                shift <- shift[[1L]]
+            }
+        }
+        x@pos_runs <- callGeneric(x@pos_runs, shift=shift)
+        x
+    }
+)
+
 setMethod("shift", "Views",
     function(x, shift=0L, use.names=TRUE)
     {
