@@ -94,10 +94,10 @@ setMethod("nearest", c("Ranges", "RangesORmissing"),
           {
             select <- match.arg(select)
             if (!missing(subject)) {
-              ol <- findOverlaps(x, subject, minoverlap = 0L, select = select)
+              ol <- findOverlaps(x, subject, maxgap = 0L, select = select)
             } else {
               subject <- x
-              ol <- findOverlaps(x, minoverlap = 0L, select = select,
+              ol <- findOverlaps(x, maxgap = 0L, select = select,
                                  drop.self = TRUE)
             }
             if (select == "all") {
