@@ -1,4 +1,5 @@
 ### R code from vignette source 'IRangesOverview.Rnw'
+### Encoding: UTF-8
 
 ###################################################
 ### code chunk number 1: options
@@ -154,7 +155,7 @@ object.size(sIntList2)
 ### code chunk number 20: list-length
 ###################################################
 length(cIntList2)
-Rle(elementLengths(cIntList2))
+Rle(elementNROWS(cIntList2))
 
 
 ###################################################
@@ -433,84 +434,7 @@ viewMaxs(xViewsList)
 
 
 ###################################################
-### code chunk number 59: RangedData-construct
-###################################################
-values <- rnorm(length(ir))
-rd <- RangedData(ir, name = letters[seq_len(length(ir))], values)
-rd
-
-
-###################################################
-### code chunk number 60: RangedData-construct-space
-###################################################
-rd <- RangedData(ir, name = letters[seq_len(length(ir))], values, 
-                 space = rep(c("chr1", "chr2"), c(3, length(ir) - 3)))
-rd
-
-
-###################################################
-### code chunk number 61: RangedData-ranges
-###################################################
-ranges(rd)
-
-
-###################################################
-### code chunk number 62: RangedData-values
-###################################################
-values(rd)
-
-
-###################################################
-### code chunk number 63: RangedData-subspace
-###################################################
-rd["chr1"]
-
-
-###################################################
-### code chunk number 64: RangedData-subspace-2
-###################################################
-all(identical(rd["chr1"], rd[1]),
-    identical(rd[1], rd[c(TRUE, FALSE)]))
-
-
-###################################################
-### code chunk number 65: RangedData-names
-###################################################
-names(rd)
-
-
-###################################################
-### code chunk number 66: RangedData-length
-###################################################
-length(rd)
-
-
-###################################################
-### code chunk number 67: RangedData-lapply
-###################################################
-lapply(rd, names)
-
-
-###################################################
-### code chunk number 68: RangedData-extract
-###################################################
-rd[[2]]
-
-
-###################################################
-### code chunk number 69: RangedData-dollar
-###################################################
-rd$values
-
-
-###################################################
-### code chunk number 70: RangedData-subset-2d
-###################################################
-rd[1:3, "name"]
-
-
-###################################################
-### code chunk number 71: sessionInfo
+### code chunk number 59: sessionInfo
 ###################################################
 toLatex(sessionInfo())
 
