@@ -102,16 +102,15 @@ test_SplitDataFrameList_subset <- function() {
     }
 }
 
-test_SplitDataFrameList_as_data.frame <- function() {
+test_SplitDataFrameList_as.data.frame <- function() {
     checkDFL2dfl <- function(DFL, dfl, compress) {
-        df <- 
-          data.frame(group = togroup(dfl), 
-                     group_name = names(dfl)[togroup(dfl)],
+        target <- 
+          data.frame(group = togroup(PartitioningByWidth(dfl)),
+                     group_name = names(dfl)[togroup(PartitioningByWidth(dfl))],
                      do.call(rbind, dfl),
                      stringsAsFactors=FALSE, row.names=NULL)
-        if (compress)
-            rownames(df) <- unlist(lapply(dfl, row.names), use.names = FALSE)
-        checkIdentical(as.data.frame(DFL), df)
+        rownames(target) <- unlist(lapply(dfl, row.names), use.names = FALSE)
+        checkIdentical(target, as.data.frame(DFL))
     }
 
     data(swiss)
@@ -214,7 +213,7 @@ test_DataFrameList_transform <- function() {
   DF <- DataFrame(state.division, state.region, state.area)
   DFL <- split(DF, DF$state.division) # NICER: split(DF, ~ state.devision)
   DFL <- transform(DFL, total.area=sum(state.area[state.region!="South"]),
-                   fraction=ifelse(total.area == 0, 0, state.area/total.area))
+                   fraction=ifelse2(total.area == 0, 0, state.area/total.area))
 
   ANS <- DataFrame(lapply(unlist(DFL, use.names=FALSE), unname))
   
