@@ -53,12 +53,6 @@ test_IRanges_combine <- function() {
   checkIdentical(mcols(c(ir1, ir2, ignore.mcols=TRUE)), NULL)
 }
 
-test_IRanges_subset <- function() { # by range
-  query <- IRanges(c(1, 4, 9), c(5, 7, 10))
-  subject <- IRanges(c(6, 8, 10), c(7, 12, 14))
-  checkIdentical(subsetByOverlaps(query, subject), query[2:3])
-}
-
 test_IRanges_annotation <- function() {
   range <- IRanges(c(1, 4), c(5, 7))
   mcols(range) <- DataFrame(a = 1:2)
